
Changelog
=========

1.0.0 (2022-06-10)
------------------

* Reverse communication without abstract classes.

0.2.0 (2022-01-16)
------------------

* Reverse communication with just one flag for user-solver communication



0.1.0 (2022-01-10)
------------------

* First release with Reverse communication code


0.0.0 (2022-01-05)
------------------

* First release on PyPI.
